summaryrefslogtreecommitdiff
path: root/python
diff options
context:
space:
mode:
Diffstat (limited to 'python')
-rw-r--r--python/variable.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/python/variable.py b/python/variable.py
index 5ae87a89..878c1cc7 100644
--- a/python/variable.py
+++ b/python/variable.py
@@ -20,7 +20,7 @@
# IN THE SOFTWARE.
import ctypes
-from typing import List, Generator, Optional, Union, Set, Dict, Tuple
+from typing import Iterable, List, Generator, Optional, Union, Set, Dict, Tuple
from dataclasses import dataclass
import binaryninja
@@ -601,11 +601,11 @@ class PossibleValueSet:
return result
@staticmethod
- def in_set_of_values(values: List[int]) -> 'PossibleValueSet':
+ def in_set_of_values(values: Iterable[int]) -> 'PossibleValueSet':
"""
Create a PossibleValueSet object for a value in a set of values.
:param list(int) values: List of integer values
:rtype: PossibleValueSet
"""
result = PossibleValueSet()
@@ -615,11 +615,11 @@ class PossibleValueSet:
return result
@staticmethod
- def not_in_set_of_values(values: List[int]) -> 'PossibleValueSet':
+ def not_in_set_of_values(values: Iterable[int]) -> 'PossibleValueSet':
"""
Create a PossibleValueSet object for a value NOT in a set of values.
:param list(int) values: List of integer values
:rtype: PossibleValueSet
"""
result = PossibleValueSet()
@@ -601,11 +601,11 @@ class PossibleValueSet:
"""
Create a PossibleValueSet object for a value in a set of values.
- :param list(int) values: List of integer values
+ :param Iterable[int] values: Iterable of integer values
:rtype: PossibleValueSet
"""
@@ -615,11 +615,11 @@ class PossibleValueSet:
"""
Create a PossibleValueSet object for a value NOT in a set of values.
- :param list(int) values: List of integer values
+ :param Iterable[int] values: Iterable of integer values
:rtype: PossibleValueSet
"""